@@ -37,7 +37,7 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <gdk/gdkx.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include <libgnome/gnome-exec.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomeui/gnome-file-entry.h>
